@@ -112,9 +112,9 @@
 #' }
 
 bandit2arm_delta <- function(data          = "choose",
-                             niter         = 4000, 
+                             niter         = 3000, 
                              nwarmup       = 1000, 
-                             nchain        = 1,
+                             nchain        = 4,
                              ncore         = 1, 
                              nthin         = 1,
                              inits         = "random",  
@@ -122,7 +122,7 @@ bandit2arm_delta <- function(data          = "choose",
                              saveDir       = NULL,
                              email         = NULL,
                              modelRegressor= FALSE,
-                             adapt_delta   = 0.8,
+                             adapt_delta   = 0.95,
                              stepsize      = 1,
                              max_treedepth = 10 ) {
   
@@ -130,13 +130,13 @@ bandit2arm_delta <- function(data          = "choose",
   if (modelRegressor) { # model regressors (for model-based neuroimaging, etc.)
     stop("** Model-based regressors are not available for this model **\n")
   } else {
-    modelPath <- system.file("stan", "bandit2arm_delta.stan", package="hBayesDM")  
+    modelPath <- system.file("exec", "bandit2arm_delta.stan", package="hBayesDM")  
   }
 
   # For using example data
   if (data=="example") {
     data <- system.file("extdata", "bandit2arm_exampleData.txt", package = "hBayesDM")
-  } else if (data=="choose") {
+  } else if (data == "choose") {
     data <- file.choose()
   }
   
@@ -240,7 +240,6 @@ bandit2arm_delta <- function(data          = "choose",
     genInitList <- "random"
   }
     
-  rstan::rstan_options(auto_write = TRUE)
   if (ncore > 1) {
     numCores <- parallel::detectCores()
     if (numCores < ncore){
@@ -250,17 +249,17 @@ bandit2arm_delta <- function(data          = "choose",
     else{
       options(mc.cores = ncore)
     }
-  }
-  else {
+  } else {
     options(mc.cores = 1)
   }
   
-  cat("************************************\n")
-  cat("** Building a model. Please wait. **\n")
-  cat("************************************\n")
+  cat("***********************************\n")
+  cat("**  Loading a precompiled model  **\n")
+  cat("***********************************\n")
   
   # Fit the Stan model
-  fit <- rstan::stan(file   = modelPath, 
+  m = stanmodels$bandit2arm_delta
+  fit <- rstan::sampling(m,
                      data   = dataList, 
                      pars   = POI,
                      warmup = nwarmup,
