@@ -114,7 +114,7 @@
 dd_exp <- function(data          = "choose",
                    niter         = 3000, 
                    nwarmup       = 1000, 
-                   nchain        = 1,
+                   nchain        = 4,
                    ncore         = 1, 
                    nthin         = 1,
                    inits         = "random",  
@@ -122,7 +122,7 @@ dd_exp <- function(data          = "choose",
                    saveDir       = NULL,
                    email         = NULL,
                    modelRegressor= FALSE,
-                   adapt_delta   = 0.8,
+                   adapt_delta   = 0.95,
                    stepsize      = 1,
                    max_treedepth = 10 ) {
 
@@ -130,7 +130,7 @@ dd_exp <- function(data          = "choose",
   if (modelRegressor) { # model regressors (for model-based neuroimaging, etc.)
     stop("** Model-based regressors are not available for this model **\n")
   } else {
-    modelPath <- system.file("stan", "dd_exp.stan", package="hBayesDM")
+    modelPath <- system.file("exec", "dd_exp.stan", package="hBayesDM")
   }
   
   # For using example data
@@ -248,7 +248,6 @@ dd_exp <- function(data          = "choose",
     genInitList <- "random"
   }
     
-  rstan::rstan_options(auto_write = TRUE)
   if (ncore > 1) {
     numCores <- parallel::detectCores()
     if (numCores < ncore){
@@ -263,12 +262,13 @@ dd_exp <- function(data          = "choose",
     options(mc.cores = 1)
   }
   
-  cat("************************************\n")
-  cat("** Building a model. Please wait. **\n")
-  cat("************************************\n")
+  cat("***********************************\n")
+  cat("**  Loading a precompiled model  **\n")
+  cat("***********************************\n")
   
   # Fit the Stan model
-  fit <- rstan::stan(file   = modelPath, 
+  m = stanmodels$dd_exp
+  fit <- rstan::sampling(m,
                      data   = dataList, 
                      pars   = POI,
                      warmup = nwarmup,
