@@ -110,7 +110,7 @@
 gng_m4 <- function(data          = "choose",
                    niter         = 5000, 
                    nwarmup       = 2000, 
-                   nchain        = 1,
+                   nchain        = 4,
                    ncore         = 1, 
                    nthin         = 1,
                    inits         = "fixed",  
@@ -118,18 +118,18 @@ gng_m4 <- function(data          = "choose",
                    saveDir       = NULL,
                    email         = NULL,
                    modelRegressor= FALSE,
-                   adapt_delta   = 0.8,
+                   adapt_delta   = 0.95,
                    stepsize      = 1,
                    max_treedepth = 10 ) {
   
   # Path to .stan model file
   if (modelRegressor) { # model regressors (for model-based neuroimaging, etc.)
-    modelPath <- system.file("stan", "gng_m4_reg.stan", package="hBayesDM")
+    modelPath <- system.file("exec", "gng_m4_reg.stan", package="hBayesDM")
     cat("************************************\n")
     cat("** Extract model-based regressors **\n")
     cat("************************************\n")
   } else {
-    modelPath <- system.file("stan", "gng_m4.stan", package="hBayesDM")
+    modelPath <- system.file("exec", "gng_m4.stan", package="hBayesDM")
   }
   
   # To see how long computations take
@@ -249,7 +249,6 @@ gng_m4 <- function(data          = "choose",
     genInitList <- "random"
   }
     
-  rstan::rstan_options(auto_write = TRUE)
   if (ncore > 1) {
     numCores <- parallel::detectCores()
     if (numCores < ncore) {
@@ -262,12 +261,17 @@ gng_m4 <- function(data          = "choose",
     options(mc.cores = 1)
   }
   
-  cat("************************************\n")
-  cat("** Building a model. Please wait. **\n")
-  cat("************************************\n")
+  cat("***********************************\n")
+  cat("**  Loading a precompiled model  **\n")
+  cat("***********************************\n")
   
   # Fit the Stan model
-  fit <- rstan::stan(file   = modelPath, 
+  if (modelRegressor) { # model regressors (for model-based neuroimaging, etc.)
+    m = stanmodels$gng_m4_reg
+  } else {
+    m = stanmodels$gng_m4
+  }
+  fit <- rstan::sampling(m, 
                      data   = dataList, 
                      pars   = POI,
                      warmup = nwarmup,
