@@ -114,7 +114,7 @@
 igt_pvl_decay <- function(data          = "choose",
                           niter         = 3000, 
                           nwarmup       = 1000,
-                          nchain        = 1,
+                          nchain        = 4,
                           ncore         = 1, 
                           nthin         = 1,
                           inits         = "random",
@@ -123,7 +123,7 @@ igt_pvl_decay <- function(data          = "choose",
                           saveDir       = NULL,
                           email         = NULL,
                           modelRegressor= FALSE,
-                          adapt_delta   = 0.8,
+                          adapt_delta   = 0.95,
                           stepsize      = 1,
                           max_treedepth = 10 ) {
   
@@ -131,7 +131,7 @@ igt_pvl_decay <- function(data          = "choose",
   if (modelRegressor) { # model regressors (for model-based neuroimaging, etc.)
     stop("** Model-based regressors are not available for this model **\n")
   } else {
-    modelPath <- system.file("stan", "igt_pvl_decay.stan", package="hBayesDM")
+    modelPath <- system.file("exec", "igt_pvl_decay.stan", package="hBayesDM")
   }
   
   # To see how long computations take
@@ -248,7 +248,6 @@ igt_pvl_decay <- function(data          = "choose",
   }
   
   # For parallel computing if using multi-cores
-  rstan::rstan_options(auto_write = TRUE)
   if (ncore > 1) {
     numCores <- parallel::detectCores()
     if (numCores < ncore) {
@@ -261,14 +260,13 @@ igt_pvl_decay <- function(data          = "choose",
     options(mc.cores = 1)
   }
   
-  
-  
-  cat("************************************\n")
-  cat("** Building a model. Please wait. **\n")
-  cat("************************************\n")
+  cat("***********************************\n")
+  cat("**  Loading a precompiled model  **\n")
+  cat("***********************************\n")
   
   # Fit the Stan model
-  fit <- rstan::stan(file   = modelPath, 
+  m = stanmodels$igt_pvl_decay
+  fit <- rstan::sampling(m, 
                      data   = dataList, 
                      pars   = POI,
                      warmup = nwarmup,
