@@ -113,7 +113,7 @@
 igt_vpp <- function(data          = "choose",
                     niter         = 3000, 
                     nwarmup       = 1000,
-                    nchain        = 1,
+                    nchain        = 4,
                     ncore         = 1, 
                     nthin         = 1,
                     inits         = "random",
@@ -122,7 +122,7 @@ igt_vpp <- function(data          = "choose",
                     saveDir       = NULL,
                     email         = NULL,
                     modelRegressor= FALSE,
-                    adapt_delta   = 0.8,
+                    adapt_delta   = 0.95,
                     stepsize      = 1,
                     max_treedepth = 10 ) {
   
@@ -130,7 +130,7 @@ igt_vpp <- function(data          = "choose",
   if (modelRegressor) { # model regressors (for model-based neuroimaging, etc.)
     stop("** Model-based regressors are not available for this model **\n")
   } else {
-    modelPath <- system.file("stan", "igt_vpp.stan", package="hBayesDM")
+    modelPath <- system.file("exec", "igt_vpp.stan", package="hBayesDM")
   }
   
   # To see how long computations take
@@ -252,7 +252,6 @@ igt_vpp <- function(data          = "choose",
   }
   
   # For parallel computing if using multi-cores
-  rstan::rstan_options(auto_write = TRUE)
   if (ncore > 1) {
     numCores <- parallel::detectCores()
     if (numCores < ncore) {
@@ -265,13 +264,13 @@ igt_vpp <- function(data          = "choose",
     options(mc.cores = 1)
   }
   
-  
-  cat("************************************\n")
-  cat("** Building a model. Please wait. **\n")
-  cat("************************************\n")
+  cat("***********************************\n")
+  cat("**  Loading a precompiled model  **\n")
+  cat("***********************************\n")
   
   # Fit the Stan model
-  fit <- rstan::stan(file   = modelPath, 
+  m = stanmodels$igt_vpp
+  fit <- rstan::sampling(m, 
                      data   = dataList, 
                      pars   = POI,
                      warmup = nwarmup,
