@@ -111,7 +111,7 @@
 prl_fictitious <- function(data          = "choose",
                            niter         = 3000, 
                            nwarmup       = 1000, 
-                           nchain        = 1,
+                           nchain        = 4,
                            ncore         = 1, 
                            nthin         = 1,
                            inits         = "random",  
@@ -119,7 +119,7 @@ prl_fictitious <- function(data          = "choose",
                            saveDir       = NULL,
                            email         = NULL,
                            modelRegressor= FALSE,
-                           adapt_delta   = 0.8,
+                           adapt_delta   = 0.95,
                            stepsize      = 1,
                            max_treedepth = 10 ) {
 
@@ -127,7 +127,7 @@ prl_fictitious <- function(data          = "choose",
   if (modelRegressor) { # model regressors (for model-based neuroimaging, etc.)
     stop("** Model-based regressors are not available for this model **\n")
   } else {
-    modelPath <- system.file("stan", "prl_fictitious.stan", package="hBayesDM")
+    modelPath <- system.file("exec", "prl_fictitious.stan", package="hBayesDM")
   }
   
   # To see how long computations take
@@ -238,7 +238,6 @@ prl_fictitious <- function(data          = "choose",
     genInitList <- "random"
   }
     
-  rstan::rstan_options(auto_write = TRUE)
   if (ncore > 1) {
     numCores <- parallel::detectCores()
     if (numCores < ncore){
@@ -253,12 +252,13 @@ prl_fictitious <- function(data          = "choose",
     options(mc.cores = 1)
   }
   
-  cat("************************************\n")
-  cat("** Building a model. Please wait. **\n")
-  cat("************************************\n")
+  cat("***********************************\n")
+  cat("**  Loading a precompiled model  **\n")
+  cat("***********************************\n")
   
   # Fit the Stan model
-  fit <- rstan::stan(file    = modelPath,
+  m = stanmodels$prl_fictitious
+  fit <- rstan::sampling(m,
                      data    = dataList, 
                      pars    = POI,
                      warmup  = nwarmup,
