@@ -111,7 +111,7 @@
 ug_bayes <- function(data          = "choose",
                      niter         = 3000, 
                      nwarmup       = 1000, 
-                     nchain        = 1,
+                     nchain        = 4,
                      ncore         = 1, 
                      nthin         = 1,
                      inits         = "random",  
@@ -119,7 +119,7 @@ ug_bayes <- function(data          = "choose",
                      saveDir       = NULL,
                      email         = NULL,
                      modelRegressor= FALSE,
-                     adapt_delta   = 0.8,
+                     adapt_delta   = 0.95,
                      stepsize      = 1,
                      max_treedepth = 10 ) {
 
@@ -127,7 +127,7 @@ ug_bayes <- function(data          = "choose",
   if (modelRegressor) { # model regressors (for model-based neuroimaging, etc.)
     stop("** Model-based regressors are not available for this model **\n")
   } else {
-    modelPath <- system.file("stan", "ug_bayes.stan", package="hBayesDM")
+    modelPath <- system.file("exec", "ug_bayes.stan", package="hBayesDM")
   }
   
   # To see how long computations take
@@ -236,7 +236,6 @@ ug_bayes <- function(data          = "choose",
     genInitList <- "random"
   }
     
-  rstan::rstan_options(auto_write = TRUE)
   if (ncore > 1) {
     numCores <- parallel::detectCores()
     if (numCores < ncore){
@@ -251,12 +250,13 @@ ug_bayes <- function(data          = "choose",
     options(mc.cores = 1)
   }
   
-  cat("************************************\n")
-  cat("** Building a model. Please wait. **\n")
-  cat("************************************\n")
+  cat("***********************************\n")
+  cat("**  Loading a precompiled model  **\n")
+  cat("***********************************\n")
   
   # Fit the Stan model
-  fit <- rstan::stan(file   = modelPath,
+  m = stanmodels$ug_bayes
+  fit <- rstan::sampling(m,
                      data   = dataList, 
                      pars   = POI,
                      warmup = nwarmup,
