@@ -112,7 +112,7 @@
 ug_delta <- function(data          = "choose",
                      niter         = 3000, 
                      nwarmup       = 1000, 
-                     nchain        = 1,
+                     nchain        = 4,
                      ncore         = 1, 
                      nthin         = 1,
                      inits         = "random",  
@@ -120,7 +120,7 @@ ug_delta <- function(data          = "choose",
                      saveDir       = NULL,
                      email         = NULL,
                      modelRegressor= FALSE,
-                     adapt_delta   = 0.8,
+                     adapt_delta   = 0.95,
                      stepsize      = 1,
                      max_treedepth = 10 ) {
 
@@ -128,7 +128,7 @@ ug_delta <- function(data          = "choose",
   if (modelRegressor) { # model regressors (for model-based neuroimaging, etc.)
     stop("** Model-based regressors are not available for this model **\n")
   } else {
-    modelPath <- system.file("stan", "ug_delta.stan", package="hBayesDM")
+    modelPath <- system.file("exec", "ug_delta.stan", package="hBayesDM")
   }
   
   # To see how long computations take
@@ -237,7 +237,6 @@ ug_delta <- function(data          = "choose",
     genInitList <- "random"
   }
     
-  rstan::rstan_options(auto_write = TRUE)
   if (ncore > 1) {
     numCores <- parallel::detectCores()
     if (numCores < ncore){
@@ -252,12 +251,13 @@ ug_delta <- function(data          = "choose",
     options(mc.cores = 1)
   }
   
-  cat("************************************\n")
-  cat("** Building a model. Please wait. **\n")
-  cat("************************************\n")
+  cat("***********************************\n")
+  cat("**  Loading a precompiled model  **\n")
+  cat("***********************************\n")
   
   # Fit the Stan model
-  fit <- rstan::stan(file   = modelPath,
+  m = stanmodels$ug_delta
+  fit <- rstan::sampling(m,
                      data   = dataList, 
                      pars   = POI,
                      warmup = nwarmup,
